###############################################################################
# zapplet - A tray applet for interfacing with Zenoss
# Copyright (C) 2008 Nathaniel McCallum <nathaniel@natemccallum.com>
# 
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2.1 of the License, or (at your option)
# any later version.
# 
# This program is distributed in the hope that it will be useful, but WITHOUT 
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
# 
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
###############################################################################

import gtk

import webbrowser

import zapplet.event
import zapplet.eventview
import zapplet.sia

class EventApplet(zapplet.sia.StatusIconApplet):

	def set_events(self, events):
		return self.__ev.set_events(events)

	def __init__(self, server):
		##
		### Build child widget
		##
		vbox = gtk.VBox()

		# Build EventView
		self.__ev = zapplet.eventview.EventView()

		# Add the EventView into a ScrolledWindow and add to the VBox
		sw = gtk.ScrolledWindow()
		sw.set_size_request(-1, 383)
		sw.set_policy(gtk.POLICY_NEVER, gtk.POLICY_AUTOMATIC)
		sw.add(self.__ev)
		vbox.pack_start(sw, False, False)

		# Create the logging stuff
		hbox = gtk.HBox()
		vbox.pack_start(hbox, False, False, 5)
		loglabel  = gtk.Label("Add Note:")
		logentry  = gtk.Entry()
		logbutton = gtk.Button(stock=gtk.STOCK_ADD)
		logentry.set_sensitive(False)
		logbutton.set_sensitive(False)

		# Pack in the logging component
		hbox.pack_start(loglabel, False, False, 5)
		hbox.pack_start(logentry)
		hbox.pack_start(logbutton, False, False, 5)

		# Pack in the View Event Console button
		hbox.pack_start(gtk.VSeparator(), False, False)
		b = gtk.Button("_View Event Console")
		b.set_image(gtk.image_new_from_stock(gtk.STOCK_INFO, gtk.ICON_SIZE_BUTTON))
		b.connect("clicked", lambda *a: zapplet.event.Event.view_event_console(server))
		hbox.pack_start(b, False, False, 5)

		##
		### Setup our signal handlers
		##
		# Only enable the log text entry if an event is selected
		togglelog = lambda s: self.__ev.get_selected_events() != [] \
				and (logentry.set_sensitive(True) or True) \
				or logentry.set_sensitive(False) \
				or logentry.set_text("")
		self.__ev.get_selection().connect("changed", togglelog)

		# Only enable the Add button if a log message has been typed
		togglelb  = lambda e: logbutton.set_sensitive(e.get_text() != "")
		logentry.connect("changed", togglelb)

		# Submit our log entry
		dolog = lambda b: [e.add_log(logentry.get_text()) for e in self.__ev.get_selected_events()] and False or logentry.set_text("")
		logbutton.connect("clicked", dolog)
		logentry.connect("activate", lambda e: logbutton.clicked())

		# Initialize the Applet
		super(EventApplet, self).__init__(vbox)

		# Preferences
		mi = gtk.ImageMenuItem(gtk.STOCK_PREFERENCES)
		mi.connect("activate", lambda si: zapplet.prefs.PreferencesWindow.factory().show_all())
		self.menu.append(mi)

		# About
		gtk.about_dialog_set_url_hook(lambda d,u: webbrowser.open(u))
		about = gtk.AboutDialog()
		about.connect("response", lambda ab,r: ab.hide())
		about.set_name("ZApplet")
		about.set_authors(["Nathaniel McCallum"])
		about.set_license("GPLv2")
		about.set_website("http://sourceforge.net/projects/zapplet/")
		mi = gtk.ImageMenuItem(gtk.STOCK_ABOUT)
		mi.connect("activate", lambda si: about.run())
		self.menu.append(mi)

		# Separator
		self.menu.append(gtk.SeparatorMenuItem())
		
		# Quit
		mi = gtk.ImageMenuItem(gtk.STOCK_QUIT)
		mi.connect("activate", gtk.main_quit)
		self.menu.append(mi)
